/*	$NetBSD: types.h,v 1.12 2018/05/08 19:35:17 christos Exp $	*/

#include <m68k/types.h>
#define	__HAVE_MM_MD_KERNACC
#define	__HAVE_MM_MD_DIRECT_MAPPED_PHYS
#define	__HAVE_MM_MD_READWRITE
#define	__HAVE_MM_MD_MMAP
#define	__HAVE_NO___THREAD
#define __HAVE_NO_PMAP_STATS
