/*	$NetBSD: disklabel.h,v 1.4 2005/12/11 12:19:16 christos Exp $	*/

#if HAVE_NBTOOL_CONFIG_H
#include <nbinclude/sun68k/disklabel.h>
#else
#include <sun68k/disklabel.h>
#endif /* HAVE_NBTOOL_CONFIG_H */
